<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>按滑鼠回到應用程式</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>清理乾淨</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>零個項目</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>表格</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>檔名</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>再試一次</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>發佈 Podcast 至 YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>演示版</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>網頁</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>桌面工具</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>背景</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>擷取</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>新增至目前頁面</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>新增至新頁面</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>新增至圖書館</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>頁面</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>新頁面</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>回復</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>更換背景</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>往上</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>往下</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>文件管理</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>網頁瀏覽</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>細</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>粗</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">細</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>粗</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>重新載入目前頁面</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>載入主頁</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>顯示書籤</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>新增書籤</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>顯示演示板</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>清除內容</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>顯示偏好設定</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>顯示圖書館</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>顯示本機桌面</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>新建檔案夾</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>建立新文件</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>匯入文件</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>匯出文件</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>於演示板開啟頁面</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>複製所選內容</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>刪除所選內容</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>新增內容至文件</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>重新命名內容</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>顯示工具</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>採寬尺寸文件(16/9)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>採一般尺寸文件 (4/3)</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>自訂文件尺寸</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>停止載入網頁</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>演示進入睡眠狀態</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>顯示虛擬鍵盤</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>錄製演示影片</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>清除項目</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>清除所有項目</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>清除桌面標注</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>清除所有桌面標注</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>清空所有元件</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>筆</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>標注文件</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>清除桌面標注</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>提示筆</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>亮點</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>選擇工具</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>選擇並修改物件</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>手型工具</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>部份截圖</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>自訂截圖範圍</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>擷取視窗</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>嵌入網頁內容</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>擷取可嵌入的網頁內容</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>在顯示器上顯示主螢幕</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>清除所有桌面標注</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>匯入 eduMedia 模擬程序</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>更新檢查</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>線條粗細</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>橡皮擦</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">顏色</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>退回</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>向左</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>前進</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>向右</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>重新載入</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>主頁</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>書籤</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>清空頁面</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>圖書館</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>顯示桌面</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>縮小</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新檔案夾</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>新文件</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>於演示板開啟</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>新增至運作中文件</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>新增所選內容至開啟的文件</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>淡色網格背景</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>深色網格背景</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>開始螢幕錄影</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>捲動頁面</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>簡報筆</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>虛擬簡報筆</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>繪線</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>文字書寫</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>新增項目至目前頁面</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>新增項目至新頁面</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>新增項目至圖書館</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>建立新頁面</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>複製頁面</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>複製目前頁面</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>匯入頁面</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>匯入外部頁面</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>暫停錄製Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcast 設定</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Podcast 錄製設定</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Flash 動畫擷取</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">擷取 Flash 動畫內容</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>網頁擷取</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>擷取網頁內容</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>螢幕擷取</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>於顯示器上顯示</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>睡眠狀態</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>虛擬鍵盤</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>淡色背景</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>淡色</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>深色背景</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>深色</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>錄製</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>多螢幕顯示</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>寬螢幕顯示 (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>一般螢幕顯示 (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>自訂螢幕大小</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>停止載入</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>退出 OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>隱藏 OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>隱藏 OpenBoard 應用程式</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>互動</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>清除背景</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>移除背景</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>開啟新手教學</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>打開教學網頁</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>重設網格大小</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation>小橡皮擦</translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation>顏色 1</translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation>顏色 2</translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation>顏色 3</translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation>顏色 4</translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation>顏色 5</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>需要驗證</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>帳號：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy 驗證</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>連接至 Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>帳號：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>儲存帳號密碼</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>元件ID =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>內容格式不支援。</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>移除頁面</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>確定要移除所選文件 &apos;%0&apos; 的一個頁面？</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>頁面大小</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>網頁</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>有可用更新，要前往網頁下載嗎？</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>目前並無更新</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>有可用更新</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>網格大小</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>目前 %1 下載失敗</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>下載完成</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>未知工具類型 %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>新增項目</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>全部已支援 (%1)</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>未知內容類型 %1</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">刪除文件的第 %1 頁</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>已刪除第 %1 頁</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>新增檔案失敗：檔案複製錯誤</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>群組</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>取消群組</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>正在儲存檔案...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>檔案已被儲存...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>正在刪除第 %1 頁</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>顏色</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>新增圖像至圖書館時發生錯誤</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>圖像擷取</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>正在載入第 %1 頁，共 %2 頁</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Cache 屬性</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>顏色：</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>形狀：</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>擷取部份螢幕</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>擷取螢幕</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>顯示桌面工具</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>於第二螢幕顯示演示板</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>於第二螢幕顯示桌面</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>顯示 OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>新檔案夾</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>第 %1 頁</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>新增圖像資料夾</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>新增圖像</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>從檔案新增頁面</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>文件 %1 複製中</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>文件 %1 已複製</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">移除頁面</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">移除文件</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">確定要移除文件 &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">清空回收桶</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">確定要清空回收桶?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">回收桶清空中</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">回收桶已清空</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">移除檔案夾</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">確定要移除檔案夾 &apos;%1&apos; 及其所有內容?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">未選擇任何文件！</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>開啟支援的檔案</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>檔案 %1 匯入中...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>匯入檔案失敗...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>從檔案夾匯入所有圖像</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>回收桶</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>開啟文件</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>新增所有圖像至文件</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>所有圖像( %1 )</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>所選內容並沒有圖像檔！</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="obsolete">
            <numerusform>確定要從所選文件 &apos;%1&apos; 移除 %n 個頁面?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>檔案夾並沒有圖像檔</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>未命名文件</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>刪除項目</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>您確定要刪除所選項目嗎？</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>檔案 &apos;%1&apos; 是由新版的 OpenBoard (%2) 建立的。開啟後可能會遺失資料。您確定要繼續嗎？</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>標題頁</translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>圖像</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>物件</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>小工具</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>所有支援的檔案 (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>已儲存檔案 %1 </translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>頁面 %2 的 %1 插入中</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>匯入成功。</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>檔案 %1 匯入成功。</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>匯入檔案 %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>第 %0 頁</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">匯出失敗。</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>取代</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation>回收桶</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>已複製 %1 個頁面</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation>我的檔案</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>已複製 %1 個頁面</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>刪除項目</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>您確定要刪除所選項目嗎？</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation>頁面 %1/%2 複製中</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copy)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">頁面 %1/%2 複製中</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="obsolete">
            <numerusform>已複製 %1 個頁面</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>檔案下載中</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">第 %0 頁</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">第 %0 頁</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>匯出過程出現警告</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>匯出檔案中...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>匯出失敗</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>無法匯出至指定位置。您沒有儲存檔案的權限。</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>匯出失敗：路徑無法被寫入</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>匯出成功。</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>匯出至 IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>以 IWB 格式匯出</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>匯出檔案中...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>成功匯出。</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>匯出失敗。</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>頁面</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>以UBZ格式匯出</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">文件匯出中...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">匯出成功。</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation> %3 的 %1 %2 匯出中</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>以 OpenBoard 格式匯出</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Export failed.</source>
        <translation>匯出失敗。</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation>匯出失敗...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>以 UBX 檔案匯出</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>匯出檔案中...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>匯出成功。</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>以 OpenBoard UBX 格式匯出</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>以 PDF 格式匯出</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">匯出文件中...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>匯出成 PDF</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">匯出成功。</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>以 PDF 格式匯出</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>頁面 %2 的 %1 匯出中</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">匯出成功。</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">匯出文件中...</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>匯出成 PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>頁面</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>以網頁資料格式匯出</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>匯出文件中...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>匯出成功。</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>匯出失敗。</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>匯出至瀏覽器</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>新增至頁面</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">設定成背景</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>新增至圖書館</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>物件資訊</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>新增至我的最愛</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>分享</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>回到檔案夾</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>從我的最愛移除</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>新建檔案夾</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>重新掃描檔案系統</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>匯入的圖像</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>音訊</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖案</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">動畫</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>互動</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>形狀</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的最愛</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>網路搜尋</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>回收桶</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>輸入檔案名稱</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>載入中</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>於延伸螢幕可見</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>於延伸螢幕可見</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>至內容來源</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>設定成背景</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>不支援的媒體格式</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>媒體錯誤：</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;此處輸入文字&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>文字顏色</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>可編輯</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>載入中...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>凍結</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>轉換為工具</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>常見檔案格式 (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>檔案 %1 匯入中...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>檔案 %1 匯入失敗。</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>匯入成功。</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>匯入失敗。</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>檔案 %1 匯入中...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>匯入成功。</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>檔案 %1 匯入失敗。</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>圖像格式 (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>可攜式檔案格式 (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF 匯入失敗。</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>頁面 %2 的 %1 匯入中</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>影片發佈到內部網路 (%1) 時有錯誤</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>發佈到內部網路中 %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>發佈</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>輸入</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;輸入 &quot;%1&quot; 在 %2 的帳號密碼&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>登入 Proxy 失敗</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>繼續</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(複製)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>文件資料庫遺失</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>英文</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>俄文</translation>
    </message>
    <message>
        <source>German</source>
        <translation>德文</translation>
    </message>
    <message>
        <source>French</source>
        <translation>法文</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>法文 (瑞士)</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>編碼器啟動失敗...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>沒有可用的Podcast編碼器...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>第 %1 部分</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>在您的桌面...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>在檔案夾 %1 中</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast 已建立 %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Podcast 錄製有錯誤 (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>預設的音頻輸入</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>無音頻錄製</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>發佈到內部網路</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>發佈至 YouTube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>感壓型提示筆</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy 登入</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">帳號：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">密碼：</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">發佈文件至網路</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">標題：</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">描述：</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">發佈</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>我的影片</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>產生預覽縮圖中...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>已產生縮圖 %1...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>第 %0 頁</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Compass</source>
        <translation>圓規</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>尺</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>量角器</translation>
    </message>
    <message>
        <source>Mask</source>
        <translation>遮罩</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>三角形</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>放大鏡</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>快取</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>整頁</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>文件更新器</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>檔案需要更新。</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>備份檔案路徑:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>選擇備份檔案夾</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>成功更新檔案!
請重新啟動程式以使用該檔案。</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>更新過程出現錯誤，原檔案並未更動。</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>檔案更新結果</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>更新檔案中</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>即將開始匯入，請稍候...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍候提醒我</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>已呼叫 %0 (方法= %1 , 狀態= %2 )</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube 驗證失敗。</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>影片上傳至 YouTube (%1)過程中有錯誤</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>上傳至 YouTube 中 %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>各類交通工具</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>寵物與動物</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>運動</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>旅遊與活動</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>遊戲</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>喜劇</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>人物與網誌</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>新聞與政治</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>娛樂</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>DIY 教學</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>非營利組織與行動主義</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>科學與技術</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>取消下載: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>已存檔案開啟時有錯誤: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>儲存錯誤: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>網路錯誤: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- 還剩下 %4 %5 </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%2 的 %1 (%3/秒) %4</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%2 的 %1 - 已停止</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 個下載</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation type="unfinished">%1 個下載</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>今日稍早</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 個項目</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>新建分頁(&amp;T)</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>複製分頁</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>關閉分頁(&amp;C)</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>關閉其他分頁 (&amp;O)</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>重新載入分頁</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>重新載入所有分頁</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>最近關閉的分頁</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>空白頁</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>無近期搜尋</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>近期搜尋</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>清除近期搜尋</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>新增至目前文件</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>頁面載入錯誤: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>於新分頁中開啟</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation>處理中...</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>發佈 Podcast 至 YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>關鍵字</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>類別</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube 帳號</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube 密碼</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Opacity</source>
        <translation>透明度</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>淡色背景</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>深色背景</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>線寬</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>粗</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>細</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>感壓筆</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation>像素</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>對話</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">對話</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">標題</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">作者</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">描述</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>建立日期</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>更新日期</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>按字母排序</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>排序方式</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>預設</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>用外部瀏覽器顯示頁面</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>虛擬鍵盤</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">按鍵大小:</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>置放在頂部（平板適用)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>置放在頂底部（電子白板適用)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>在按鈕下顯示文字</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>桌面工具</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>橫向</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>縱向</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>軟體更新</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>啟動時檢查更新</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>網際網路</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>主頁：</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>工具列</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>電子筆</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>提示筆</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>版本： …</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>於第二螢幕或投影機顯示內部網頁內容</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>多重顯示</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>控制螢幕與顯示螢幕之間切換</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>啟動模式：</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>演示板</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy 使用者：</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>貢獻</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>深色背景</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>透明度</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>淡色背景</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>內建虛擬鍵盤按鍵大小：</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>使用系統鍵盤 (推薦)</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>網格</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation>天</translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>擷取 flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">選擇要擷取的 flash 動畫</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>空白頁</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>應用程式名稱</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>建立應用程式</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
